@@ -101,7 +101,16 @@ KQuickStyleItem::KQuickStyleItem(QQuickItem *parent)
         // desktop style, to be used for metrics, options and painting.
         KSharedConfig::Ptr kdeglobals = KSharedConfig::openConfig();
         KConfigGroup cg(kdeglobals, QStringLiteral("KDE"));
-        s_style.reset(QStyleFactory::create(cg.readEntry("widgetStyle", QStringLiteral("Fusion"))));
+        const QString defaultStyleName = QStringLiteral("Fusion");
+        s_style.reset(QStyleFactory::create(cg.readEntry("widgetStyle", defaultStyleName)));
+        if (!s_style) {
+            s_style.reset(QStyleFactory::create(defaultStyleName));
+            // Prevent inevitable crashes on nullptr dereference
+            if (!s_style) {
+                qWarning() << "org.kde.desktop: Could not find any QStyle such as Breeze or Fusion";
+                ::exit(EXIT_FAILURE);
+            }
+        }
     }
 
     m_font = qApp->font();
@@ -1958,7 +1967,12 @@ QSGNode *KQuickStyleItem::updatePaintNode(QSGNode *node, UpdatePaintNodeData *)
 #endif
 
     styleNode->setTexture(window()->createTextureFromImage(m_image, QQuickWindow::TextureCanUseAtlas));
-    styleNode->setBounds(boundingRect());
+    QRectF bounds = boundingRect();
+    QPointF globalPixelPos = mapToScene(bounds.topLeft()) * window()->effectiveDevicePixelRatio();
+    QPointF posAdjust = QPointF(globalPixelPos.x() - std::round(globalPixelPos.x()), globalPixelPos.y() - std::round(globalPixelPos.y()))
+        / window()->effectiveDevicePixelRatio();
+    bounds.moveTopLeft(bounds.topLeft() - posAdjust);
+    styleNode->setBounds(bounds);
     styleNode->setDevicePixelRatio(window()->effectiveDevicePixelRatio());
 
     styleNode->setPadding(m_border.left(), m_border.top(), m_border.right(), m_border.bottom());
